/*----------------------------------------------------------------|
//       Indicator Export Expert v1, by juanchoc & neo            |
//----------------------------------------------------------------|
//                                                                |
//                                                                |
//       This EA was made to easily export indicators results     |
//       to CSV files for further manipulation and/or analisis    |
//       of them.                                                 |
//                                                                |
//       Instructions:                                            |
//       Modify the InitializeHeaderFile() function so that it    |
//       displays the CSV column headers in the same order        |
//       you set the indicators.                                  |
//       Modify the WriteHistoryData() function so that it        |
//       displays the indicators you want to export (remember     |
//       to place them on the same order you used on the          |
//       InitializeHeaderFile()).                                 |
//       Compile the expert.                                      |
//       Run the expert on the desired time range using the       |
//       Strategy Tester.                                         |
//       Results are saved at your Metatrader/tester/files/       |
//       folder.                                                  |
//                                                                |
//                                                                |
//       ***PLEASE DONT MODIFY OR DELETE THIS HEADER**            |
//             Copyright 2006, by juanchoc & neo.                 |
//                  juan@forexproyect.com.ar                      |
//---------------------------------------------------------------*/
#property copyright "#copyright#"
#property link      "#link#"
#property show_inputs

extern int bars = 1000;

int      CSVHandle = -1;

int OpenHistoryFile()
{
   string name;
   name = Symbol() + "_DATA";
      CSVHandle = FileOpen(name + ".csv", FILE_CSV|FILE_WRITE, ',');
      if (CSVHandle < 0) return(-1);
   return (0);
}

int InitializeHeaderFile()
{
   FileWrite(CSVHandle,"DATE","TIME","OPEN","HIGH","LOW","CLOSE","AC","AD","ALLIGATOR","ADX","ATR","AO","BEARPOWER","BANDS","BULLSPOWER","FRACTALS","FORCE","ENVELOPE","DEMARK","CCI","STOCH","WPR","STDDEV","RVI","RSI","SAR","OBV","MACD","OSMA","SMA","EMA","MFI","MOMENTUM","BWMFI","ICHI","GATOR","-SMA10-");
   return(0);
}

void WriteHistoryData()
{
   if (CSVHandle >= 0) {
      for (int k=bars-1; k>=0;k--)
         FileWrite(CSVHandle, 
         TimeToStr(Time[k], TIME_DATE), 
         TimeToStr(Time[k], TIME_MINUTES),
         DoubleToStr(Open[k], k), 
         DoubleToStr(High[k], k), 
         DoubleToStr(Low[k], k), 
         DoubleToStr(Close[k], k),
         iAC(NULL,0,k), 
         iAD(NULL,0,k),
         iAlligator(NULL,0,13,8,8,5,5,3,MODE_SMMA,PRICE_MEDIAN,MODE_GATORJAW,k),
         iADX(NULL,0,14,PRICE_HIGH,MODE_MAIN,k),
         iATR(NULL,0,14,k),
         iAO(NULL,0,k),
         iBearsPower(NULL,0,13,PRICE_CLOSE,k),
         iBands(NULL,0,20,2,0,PRICE_LOW,MODE_LOWER,k),
         iBullsPower(NULL, 0, 13,PRICE_CLOSE,k),
         iFractals(NULL, 0, MODE_UPPER, k),
         iForce(NULL,0,10,MODE_SMA,PRICE_CLOSE,k),
         iEnvelopes(NULL,0,10,MODE_SMA,10,PRICE_CLOSE,0.2,MODE_UPPER,k),
         iDeMarker(NULL,0,13,k),
         iCCI(Symbol(),0,14,PRICE_TYPICAL,k),
         iStochastic(NULL,0,5,3,3,MODE_SMA,0,MODE_MAIN,k),
         iWPR(NULL,0,14,k),
         iStdDev(NULL,0,10,0,MODE_EMA,PRICE_CLOSE,k),
         iRVI(NULL, 0, 10,MODE_MAIN,k),
         iRSI(NULL,0,14,PRICE_CLOSE,k),
         iSAR(NULL,0,0.02,0.2,k),
         iOBV(NULL,0,PRICE_CLOSE,k),
         iMACD(NULL,0,12,26,9,PRICE_CLOSE,MODE_MAIN,k),
         iOsMA(NULL,0,12,26,9,PRICE_OPEN,k),
         iMA(NULL,0,5,8,MODE_SMMA,PRICE_MEDIAN,k),
         iMA(NULL,0,5,8,MODE_EMA,PRICE_MEDIAN,k),
         iMFI(NULL,0,14,k),
         iMomentum(NULL,0,10,PRICE_CLOSE,k),
         iBWMFI(NULL,0,k),
         iIchimoku(NULL,0,9,26,52,MODE_TENKANSEN,k),
         iGator(NULL,0,13,8,8,5,5,3,MODE_SMMA,PRICE_MEDIAN,MODE_UPPER,k),
         iMA(NULL,0,10,0,MODE_SMA,PRICE_CLOSE,k));
         
   }
}

//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
//----
   OpenHistoryFile();
   InitializeHeaderFile();
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
//----
      if (CSVHandle >= 0) {
      FileClose(CSVHandle);
      CSVHandle = -1; 
      Comment(Symbol() + "_DATA written and dile closed");
   }

//----
   return(0);
  }
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
//----
   WriteHistoryData();
//----
   return(0);
  }
//+------------------------------------------------------------------+